@@ -2,9 +2,10 @@ package FFI::Platypus::Lang::Fortran;
 
 use strict;
 use warnings;
-use FFI::Platypus::Lang::Fortran::ConfigData;
+use File::ShareDir::Dist qw( dist_config );
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
+my $config = dist_config 'FFI-Platypus-Lang-Fortran';
 
 =head1 NAME
 
@@ -35,7 +36,9 @@ Fortran 90/95:
 
 Perl:
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
+ 
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('Fortran');
  $ffi->lib('./libadd.so'); # or add.dll on Windows
  
@@ -79,15 +82,6 @@ Fortran is pass by reference, which means that you need to pass pointers.
 Confusingly Platypus uses a star (C<*>) suffix to indicate a pointer, and
 Fortran uses a star to indicate the size of types.
 
-This module currently uses and is bundled with a fork of L<ExtUtils::F77>
-called L<Module::Build::FFI::Fortran::ExtUtilsF77>.  It is used to probe
-for a Fortran compiler, which can be problematic if you want to bundle
-Fortran 90 or Fortran 95 code, as it only knows about Fortran 77.  On some
-platforms (such as those using C<gfortran>) the same command is invoked to
-build all versions of fortran.  On some (usually those with a C<f77> command)
-a C<f90> or C<f95> command is required to build code for newer versions of
-Fortran.  We attempt to work around these limitations.
-
 =head1 METHODS
 
 Generally you will not use this class directly, instead interacting with
@@ -106,7 +100,7 @@ are libffi native types.
 
 sub native_type_map
 {
-  FFI::Platypus::Lang::Fortran::ConfigData->config('type');
+  $config->{'type'};
 }
 
 =head2 mangler
@@ -121,8 +115,8 @@ Returns a subroutine reference that will "mangle" Fortran names.
 sub mangler
 {
   my($class, @libs) = @_;
-  
-  FFI::Platypus::Lang::Fortran::ConfigData->config('f77')->{'trailing_underscore'}
+
+  $config->{'f77'}->{'trailing_underscore'}
   ? sub { return "$_[0]_" }
   : sub { $_[0] };
 }
@@ -140,9 +134,9 @@ Fortran:
 
 Perl:
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('Fortran');
  $ffi->lib('./libsub.so');
  
@@ -153,12 +147,12 @@ Perl:
  
  print "$value\n";
 
-B<Discussion>: A Fortran "subroutine" is just a function that doesn't 
-return a value.  In Fortran 77 variables that start wit the letter I are 
-integers unless declared otherwise.  Fortran is also pass by reference, 
-which means under the covers Fortran passes its arguments as pointers to 
-the data, and you have to remember to pass in a reference to a value in 
-Perl in cases where you would normally pass in a simple value to a C 
+B<Discussion>: A Fortran "subroutine" is just a function that doesn't
+return a value.  In Fortran 77 variables that start wit the letter I are
+integers unless declared otherwise.  Fortran is also pass by reference,
+which means under the covers Fortran passes its arguments as pointers to
+the data, and you have to remember to pass in a reference to a value in
+Perl in cases where you would normally pass in a simple value to a C
 function.
 
 =head2 Call Fortran 90 / 95
@@ -170,7 +164,7 @@ Fortran:
  recursive function fib(x) result(ret)
    integer, intent(in) :: x
    integer :: ret
-   
+ 
    if (x == 1 .or. x == 2) then
      ret = 1
    else
@@ -181,9 +175,9 @@ Fortran:
 
 Perl:
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('Fortran');
  $ffi->lib('./libfib.so');
  
@@ -194,7 +188,7 @@ Perl:
    print fib(\$_), "\n";
  }
 
-B<Discussion>: Fortran 90 has "advanced" features such as recursion and 
+B<Discussion>: Fortran 90 has "advanced" features such as recursion and
 pointers, which can now be used in Perl too.
 
 =head2 Complex numbers
@@ -208,7 +202,7 @@ Fortran:
    complex*16 :: c
    real*8 :: r
    real*8 :: i
-   
+ 
    r = real(c)
    i = aimag(c)
  
@@ -216,11 +210,12 @@ Fortran:
 
 Perl:
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  use Math::Complex;
  
- my $ffi->lang('Fortran');
- my $ffi->lib('./libcomplex.so');
+ my $ffi = FFI::Platypus->new( api => 1 );
+ $ffi->lang('Fortran');
+ $ffi->lib('./libcomplex.so');
  
  $ffi->attach(
    complex_decompose => ['real_8[2]','real_8*','real_8*'] => 'void',
@@ -248,19 +243,19 @@ Perl:
 B<Discussion>: More recent versions of C<libffi> and L<FFI::Platypus>
 support complex types, but not pointers to complex types, so they
 aren't (yet) much use when calling Fortran, which is pass by reference.
-There is a work  around, however, at least for complex types passes as 
+There is a work  around, however, at least for complex types passes as
 arguments.  They are really two just two C<real*4> or C<real*8> types
 joined together like an array or record of two elements.  Thus we can
 pass in a complex type to a Fortran subroutine as an array of two
 floating points.  Take  care though, as this technique DOES NOT work
 for return types.
 
-From my research, some Fortran compilers pass in the return address of 
-the return value as the first argument for functions that return a 
-C<complex> type.  This is not the case for Gnu Fortran, the compiler 
-that I have been testing with, but if your compiler does use this 
-convention you could pass in the "return value" as a two element array, 
-as we did in the above example.  I have not been able to test this 
+From my research, some Fortran compilers pass in the return address of
+the return value as the first argument for functions that return a
+C<complex> type.  This is not the case for Gnu Fortran, the compiler
+that I have been testing with, but if your compiler does use this
+convention you could pass in the "return value" as a two element array,
+as we did in the above example.  I have not been able to test this
 though.
 
 =head2 Fixed length array
@@ -280,9 +275,9 @@ Fortran:
 
 Perl:
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('Fortran');
  $ffi->lib('./libfixed.so');
  
@@ -303,8 +298,8 @@ Output:
            45
            50
 
-B<Discussion>: In Fortran arrays are 1 indexed unlike Perl and C where 
-arrays are 0 indexed.  Perl arrays are passed in from Perl using 
+B<Discussion>: In Fortran arrays are 1 indexed unlike Perl and C where
+arrays are 0 indexed.  Perl arrays are passed in from Perl using
 Platypus as a array reference.
 
 =head2 Multidimensional arrays
@@ -317,7 +312,7 @@ Fortran:
    implicit none
    integer, dimension(2,5) :: a
    integer :: i,n
-   
+ 
    do i=1,5
      print *, a(1,i), a(2,i)
    end do
@@ -325,9 +320,9 @@ Fortran:
 
 Perl:
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang('Fortran');
  $ffi->lib('./libfixed.so');
  
@@ -343,16 +338,16 @@ Output:
            35          40
            45          50
 
-B<Discussion>: Perl does not generally support multi-dimensional arrays 
-(though they can be achieved using lists of references).  In Fortran, 
-multidimensional arrays are stored as a contiguous series of bytes, so 
-you can pass in a single dimensional array to a Fortran function or 
+B<Discussion>: Perl does not generally support multi-dimensional arrays
+(though they can be achieved using lists of references).  In Fortran,
+multidimensional arrays are stored as a contiguous series of bytes, so
+you can pass in a single dimensional array to a Fortran function or
 subroutine assuming it has sufficent number of values.
 
-Platypus updates any values that have been changed by Fortran when the 
+Platypus updates any values that have been changed by Fortran when the
 Fortran code returns.
 
-One thing to keep in mind is that Fortran arrays are "column-first", 
+One thing to keep in mind is that Fortran arrays are "column-first",
 which is the opposite of C/C++, which could be termed "row-first".
 
 =head2 Variable-length array
@@ -367,9 +362,9 @@ Fortran:
    integer, dimension(size) :: a
    integer :: i
    integer :: ret
-   
+ 
    ret = 0
-   
+ 
    do i=1,size
      ret = ret + a(i)
    end do
@@ -377,9 +372,9 @@ Fortran:
 
 Perl:
 
- use FFI::Platypus;
+ use FFI::Platypus 1.00;
  
- my $ffi = FFI::Platypus->new;
+ my $ffi = FFI::Platypus->new( api => 1 );
  $ffi->lang("Fortran");
  $ffi->lib("./libvar_array.so");
  
@@ -393,7 +388,7 @@ Perl:
  
  my @a = (1..10);
  my @b = (25..30);
-
+ 
  print sum_array(1..10), "\n";
  print sum_array(25..30), "\n";
 
@@ -402,11 +397,11 @@ Output:
  55
  165
 
-B<Discussion>: Fortran allows variable-length arrays.  To indicate a 
-variable length array use the C<[]> notation without a length.  Note 
-that this works for argument types, where Perl knows the length of an 
-array, but it will not work for return types, where Perl has no way of 
-determining the size of the returned array (you can probably fake it 
+B<Discussion>: Fortran allows variable-length arrays.  To indicate a
+variable length array use the C<[]> notation without a length.  Note
+that this works for argument types, where Perl knows the length of an
+array, but it will not work for return types, where Perl has no way of
+determining the size of the returned array (you can probably fake it
 with an C<opaque> type and a wrapper function though).
 
 =head1 SUPPORT
@@ -454,7 +449,7 @@ maintainer.  Extreme caution: if you like that sort of thing.
 
 The Core Platypus documentation.
 
-=item L<Module::Build::FFI::Fortran>
+=item L<FFI::Build> + L<FFI::Build::File::Fortran>
 
 Bundle Fortran with your FFI / Perl extension.
 
@@ -471,45 +466,5 @@ This software is copyright (c) 2015 by Graham Ollis
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-This software comes bundled with a forked version of L<ExtUtils::F77>
-called L<Module::Build::FFI::Fortran::ExtUtilsF77>.
-L<ExtUtils::F77> comes with this statement regarding its license:
-
-  Copyright (c) 2001 by Karl Glazebrook. All rights reserved.  This distribution 
-  is free software; you can redistribute it and/or modify it under the same 
-  terms as Perl itself.
-
-  THIS SOFTWARE IS PROVIDED BY THE CONTRIBUTORS ``AS IS'' AND ANY EXPRESS
-  OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-  ARE DISCLAIMED.  IN NO EVENT SHALL THE CONTRIBUTORS BE LIABLE FOR ANY
-  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
-  STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
-  IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
-  POSSIBILITY OF SUCH DAMAGE.
-
-  BECAUSE THE PROGRAM IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-  FOR THE PROGRAM, TO THE EXTENT PERMITTED BY APPLICABLE LAW.  EXCEPT WHEN
-  OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-  PROVIDE THE PROGRAM "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-  EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-  WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
-  THE ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE PROGRAM IS
-  WITH YOU.  SHOULD THE PROGRAM PROVE DEFECTIVE, YOU ASSUME THE COST OF
-  ALL NECESSARY SERVICING, REPAIR OR CORRECTION.
-
-  IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-  WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-  REDISTRIBUTE THE PROGRAM AS PERMITTED ABOVE, BE LIABLE TO YOU FOR
-  DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL OR CONSEQUENTIAL
-  DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE THE PROGRAM
-  (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING RENDERED
-  INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A FAILURE OF
-  THE PROGRAM TO OPERATE WITH ANY OTHER PROGRAMS), EVEN IF SUCH HOLDER
-  OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
-
 =cut
 
